@@ -31,7 +31,7 @@
 #include "mimetypes.h"
 #include "pluginmanager.h"
 
-K_PLUGIN_FACTORY_WITH_JSON(ExtractFileItemActionFactory, "extractfileitemaction.json", registerPlugin<ExtractFileItemAction>();)
+K_PLUGIN_CLASS_WITH_JSON(ExtractFileItemAction, "extractfileitemaction.json")
 
 using namespace Kerfuffle;
 
@@ -43,7 +43,7 @@ ExtractFileItemAction::ExtractFileItemAction(QObject* parent, const QVariantList
 QList<QAction*> ExtractFileItemAction::actions(const KFileItemListProperties& fileItemInfos, QWidget* parentWidget)
 {
     QList<QAction*> actions;
-    const QIcon icon = QIcon::fromTheme(QStringLiteral("ark"));
+    const QIcon icon = QIcon::fromTheme(QStringLiteral("archive-extract"));
 
     bool readOnlyParentDir = false;
     QList<QUrl> supportedUrls;
@@ -87,6 +87,7 @@ QList<QAction*> ExtractFileItemAction::actions(const KFileItemListProperties& fi
 
     QAction *extractMenuAction = new QAction(i18nc("@action:inmenu Extract submenu in Dolphin context menu", "Extract"), parentWidget);
     extractMenuAction->setMenu(extractMenu);
+    extractMenuAction->setIcon(icon);
 
     // #189177: disable extract menu in read-only folders.
     if (readOnlyParentDir) {
