@@ -34,10 +34,10 @@
 #include "jobs.h"
 
 #include <KConfig>
-#include <kjobtrackerinterface.h>
-#include <kmessagebox.h>
+#include <KJobTrackerInterface>
+#include <KIO/JobTracker>
 #include <KLocalizedString>
-#include <kio/job.h>
+#include <KMessageBox>
 
 #include <QFileInfo>
 #include <QDir>
@@ -92,10 +92,16 @@ bool AddToArchive::showAddDialog()
 {
     qCDebug(ARK) << "Opening add dialog";
 
+    if (m_filename.isEmpty()) {
+        detectFileName();
+    }
+
     QPointer<Kerfuffle::CreateDialog> dialog = new Kerfuffle::CreateDialog(
-        Q_NULLPTR, // parent
+        nullptr, // parent
         i18n("Compress to Archive"), // caption
-        QUrl::fromLocalFile(m_firstPath)); // startDir
+        QUrl::fromLocalFile(QFileInfo(m_filename).path())); // startDir
+
+    dialog->setFileName(QFileInfo(m_filename).fileName());
 
     bool ret = dialog.data()->exec();
 
@@ -146,14 +152,14 @@ bool AddToArchive::doKill()
 void AddToArchive::slotStartJob()
 {
     if (m_entries.isEmpty()) {
-        KMessageBox::error(NULL, i18n("No input files were given."));
+        KMessageBox::error(nullptr, i18n("No input files were given."));
         emitResult();
         return;
     }
 
     if (m_filename.isEmpty()) {
         if (m_autoFilenameSuffix.isEmpty()) {
-            KMessageBox::error(Q_NULLPTR, xi18n("You need to either supply a filename for the archive or a suffix (such as rar, tar.gz) with the <command>--autofilename</command> argument."));
+            KMessageBox::error(nullptr, xi18n("You need to either supply a filename for the archive or a suffix (such as rar, tar.gz) with the <command>--autofilename</command> argument."));
             emitResult();
             return;
         }
@@ -164,20 +170,7 @@ void AddToArchive::slotStartJob()
             return;
         }
 
-        const QString base = detectBaseName(m_entries);
-
-        QString finalName = base + QLatin1Char( '.' ) + m_autoFilenameSuffix;
-
-        //if file already exists, append a number to the base until it doesn't
-        //exist
-        int appendNumber = 0;
-        while (QFileInfo::exists(finalName)) {
-            ++appendNumber;
-            finalName = base + QLatin1Char( '_' ) + QString::number(appendNumber) + QLatin1Char( '.' ) + m_autoFilenameSuffix;
-        }
-
-        qCDebug(ARK) << "Autoset filename to" << finalName;
-        m_filename = finalName;
+        detectFileName();
     }
 
     if (m_changeToFirstPath) {
@@ -208,12 +201,31 @@ void AddToArchive::slotStartJob()
     m_createJob->start();
 }
 
+void AddToArchive::detectFileName()
+{
+    const QString base = detectBaseName(m_entries);
+    const QString suffix = !m_autoFilenameSuffix.isEmpty() ? QLatin1Char( '.' ) + m_autoFilenameSuffix : QString();
+
+    QString finalName = base + suffix;
+
+    //if file already exists, append a number to the base until it doesn't
+    //exist
+    int appendNumber = 0;
+    while (QFileInfo::exists(finalName)) {
+        ++appendNumber;
+        finalName = base + QLatin1Char( '_' ) + QString::number(appendNumber) + suffix;
+    }
+
+    qCDebug(ARK) << "Autoset filename to" << finalName;
+    m_filename = finalName;
+}
+
 void AddToArchive::slotFinished(KJob *job)
 {
-    qCDebug(ARK) << "AddToArchive job finished";
+    qCDebug(ARK) << "job finished";
 
     if (job->error() && !job->errorString().isEmpty()) {
-        KMessageBox::error(Q_NULLPTR, job->errorString());
+        KMessageBox::error(nullptr, job->errorString());
     }
 
     emitResult();
